@@ -4,7 +4,7 @@
 * acp_common [Deutsch — Du]
 *
 * @package language
-* @version $Id: common.php 515 2010-11-13 22:41:00Z philippk $
+* @version $Id: common.php 581 2011-11-22 19:15:46Z philippk $
 * @copyright (c) 2005 phpBB Group; 2006 phpBB.de
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -330,6 +330,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Datenbank-Server',
 	'DATABASE_SIZE'		=> 'Datenbank-Größe',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Das Überladen von Funktionen ist fehlerhaft konfiguriert',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> muss entweder 0 oder 4 sein. Du kannst den aktuellen Wert auf der Seite <samp>PHP-Information</samp> prüfen.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Die transparente Zeichenkodierung ist fehlerhaft konfiguriert',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> muss 0 sein. Du kannst den aktuellen Wert auf der Seite <samp>PHP-Information</samp> prüfen.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'Die HTTP-Eingabe-Kodierung ist fehlerhaft konfiguriert',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> muss auf <samp>pass</samp> eingestellt sein. Du kannst den aktuellen Wert auf der Seite <samp>PHP-Information</samp> prüfen.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'Die HTTP-Ausgabe-Kodierung ist fehlerhaft konfiguriert',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> muss auf <samp>pass</samp> eingestellt sein. Du kannst den aktuellen Wert auf der Seite <samp>PHP-Information</samp> prüfen.',
+
 	'FILES_PER_DAY'		=> 'Dateianhänge pro Tag',
 	'FORUM_STATS'		=> 'Board-Statistik',
 
