@@ -4,7 +4,7 @@
 * common [Deutsch — Du]
 *
 * @package language
-* @version $Id: common.php 567 2011-06-16 20:29:06Z philippk $
+* @version $Id: common.php 582 2011-11-25 20:57:11Z philippk $
 * @copyright (c) 2005 phpBB Group; 2006 phpBB.de
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -168,6 +168,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Du musst einen Betreff angeben, wenn du eine neue Nachricht verfassen möchtest.',
 	'ENABLED'							=> 'Aktiviert',
 	'ENCLOSURE'							=> 'Texterkennungszeichen',
+	'ENTER_USERNAME'					=> 'Einen Benutzernamen angeben',
 	'ERR_CHANGING_DIRECTORY'			=> 'Das Verzeichnis konnte nicht gewechselt werden.',
 	'ERR_CONNECTING_SERVER'				=> 'Fehler beim Verbindungsaufbau zum Server.',
 	'ERR_JAB_AUTH'						=> 'Die Anmeldung am Jabber-Server war nicht erfolgreich.',
@@ -203,6 +204,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Die Forumsregeln lesen',
 	'FROM'					=> 'von',
 	'FSOCK_DISABLED'		=> 'Dieser Vorgang kann nicht abgeschlossen werden, da die <var>fsockopen</var>-Funktion deaktiviert wurde oder weil der angegebene Server nicht gefunden werden konnte.',
+	'FSOCK_TIMEOUT'			=> 'Beim Lesen des Datenstroms ist eine Zeitüberschreitung aufgetreten.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-Server',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-Server, auf dem sich deine Website befindet.',
@@ -655,6 +657,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> ungelesene Nachrichten',
 	'UNREAD_POST'			=> 'Ungelesener Beitrag',
 	'UNREAD_POSTS'			=> 'Ungelesene Beiträge',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Bist du dir sicher, dass du dieses Forum nicht mehr beobachten möchtest?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Bist du dir sicher, dass du das Forum „%s“ nicht mehr beobachten möchtest?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Bist du dir sicher, dass du dieses Thema nicht mehr beobachten möchtest?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Bist du dir sicher, dass du das Thema „%s“ nicht mehr beobachten möchtest?',
 	'UNWATCHED_FORUMS'			=> 'Du beobachtest die ausgewählten Foren nicht mehr.',
 	'UNWATCHED_TOPICS'			=> 'Du beobachtest die ausgewählten Themen nicht mehr.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Du beobachtest die ausgewählten Elemente nicht mehr.',
@@ -703,6 +709,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Verwarnungen',
 	'WARN_USER'			=> 'Benutzer verwarnen',
+	'WATCH_FORUM_CONFIRM'	=> 'Bist du dir sicher, dass du dieses Forum beobachten möchtest?',
+	'WATCH_FORUM_DETAILED'	=> 'Bist du dir sicher, dass du das Forum „%s“ beobachten möchtest?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Bist du dir sicher, dass du dieses Thema beobachten möchtest?',
+	'WATCH_TOPIC_DETAILED'	=> 'Bist du dir sicher, dass du das Thema „%s“ beobachten möchtest?',
 	'WELCOME_SUBJECT'	=> 'Willkommen auf %s',
 	'WEBSITE'			=> 'Website',
 	'WHOIS'				=> 'Whois',
